@@ -283,8 +283,21 @@ def how_long_ago(anytime, since=None):
     '10 minutes ago'
 
     """
+
+    def as_datetime(anytime):
+        """Convert value to datetime"""
+        if isinstance(anytime, datetime.datetime):
+            return anytime
+        elif isinstance(anytime, datetime.date):
+            return datetime.datetime(anytime.year, anytime.month, anytime.day)
+        elif anytime is None:
+            msg = 'date, datetime or timestamp required (None passed)'
+            raise TypeError(msg)
+        else:
+            return datetime.datetime.fromtimestamp(anytime)
+
     right_now = since or now()
-    if anytime < right_now:
+    if as_datetime(anytime) < right_now:
         return how_long(anytime, right_now) + ' ago'
     else:
         return how_long(right_now, anytime) + ' from now'
@@ -653,7 +666,15 @@ def get_template(template_name='default', theme='default'):
         os.path.join(path, theme, template_name + '.html')
     )
     alt_pathname = pathname.endswith('.html') and pathname[:-4] + 'pug'
-    logger.debug('alt_pathname: %r', alt_pathname)
+    default_pathname = os.path.realpath(
+        os.path.join(
+            zoom.tools.zoompath(
+                'zoom/_assets/web/themes/default',
+                template_name + '.pug'
+            )
+        )
+    )
+    logger.debug('default_pathname: %r', alt_pathname)
 
     if isfile(pathname):
         logger.debug('get_template %r', pathname)
@@ -662,11 +683,18 @@ def get_template(template_name='default', theme='default'):
 
     elif alt_pathname and isfile(alt_pathname):
         basedir = os.path.split(alt_pathname)[0]
-        logger.debug('get_template %r', alt_pathname)
+        logger.info('get_template %r', alt_pathname)
         logger.debug('basedir %r', basedir)
         with open(alt_pathname, 'rb') as reader:
             return zoom.tools.pug(reader.read().decode('utf8'), basedir=basedir)
 
+    elif default_pathname and isfile(default_pathname):
+        basedir = os.path.split(default_pathname)[0]
+        logger.debug('get_template %r', default_pathname)
+        logger.debug('basedir %r', basedir)
+        with open(default_pathname, 'rb') as reader:
+            return zoom.tools.pug(reader.read().decode('utf8'), basedir=basedir)
+
     else:
         if template_name == 'default':
             logger.error('default template %s missing', pathname)
